@@ -12,7 +12,7 @@
 #include <vector>
 #include <memory>
 
-constexpr auto TESTED_YTMUSICAPI_VERSION = "1.1.0";
+constexpr auto TESTED_YTMUSICAPI_VERSION = "1.3.1";
 
 struct YTMusicPrivate;
 
@@ -67,7 +67,7 @@ struct Song : public Media {
 };
 
 struct Album {
-    std::string browse_id;
+    std::optional<std::string> browse_id;
     std::string title;
     std::string type;
     std::vector<meta::Artist> artists;
@@ -275,7 +275,7 @@ struct Playlist {
 }
 
 struct Lyrics {
-    std::string source;
+    std::optional<std::string> source;
     std::string lyrics;
 };
 
@@ -293,7 +293,7 @@ public:
     std::vector<search::SearchResultItem> search(const std::string &query,
                                                  const std::optional<std::string> &filter = std::nullopt,
                                                  const std::optional<std::string> &scope = std::nullopt,
-                                                 const int limit = 20,
+                                                 const int limit = 100,
                                                  const bool ignore_spelling = false) const;
 
     /// https://ytmusicapi.readthedocs.io/en/latest/reference.html#ytmusicapi.YTMusic.get_artist
